@@ -7,7 +7,8 @@ use strict;
 
 package XML::Compile::SOAP::HTTPDaemon;
 use vars '$VERSION';
-$VERSION = '0.10';
+$VERSION = '0.11';
+
 use base 'XML::Compile::SOAP::Daemon';
 
 use Log::Report 'xml-compile-soap-daemon', syntax => 'SHORT';
@@ -165,7 +166,8 @@ sub acceptResponse($$)
 
     my $resp   = HTTP::Response->new($status);
     $resp->protocol($request->protocol);  # match request
-    $resp->content($xml->toString);
+    my $s = $resp->content($xml->toString);
+    { use bytes; $self->header('Content-Length' => length $s); }
     $self->headersForXML($resp);
 
     if(substr($request->method, 0, 2) eq 'M-')
@@ -179,7 +181,8 @@ sub soapFault($$$$)
 {   my ($self, $version, $data, $rc, $abstract) = @_;
     my $doc  = $self->SUPER::soapFault($version, $data);
     my $resp = HTTP::Response->new($rc, $abstract);
-    $resp->content($doc->toString);
+    my $s = $resp->content($doc->toString);
+    { use bytes; $self->header('Content-Length' => length $s); }
     $self->headersForXML($resp);
     $resp;
 }
